function spyFrame(fmesh)
% spyFrame  View sparse stiffness matrices from 2D truss FEA
%
% Synopsis:  spyFrame(fmesh)
%
% Input:     fmesh = (optional) name of *.msh file to define the mesh
%                    Default = 'longFrame.msh'
%
% Output:    Spy plots of the unconstrained and constrained stiffness matrices

if nargin<1,  fmesh = 'longFrame.msh';   end

fprintf('\nParsing input file...');
[XY,E,C,L,M,disc] = parseMesh(fmesh,0);
fprintf(' done\n\n');

K = stiffness(XY,E,M);          %  Unconstrained stiffness matrix
[Kc,fc] = constrain(K,C,L);     %  Apply loads and constraints

f = figure;
subplot(1,2,1)
spy(K)
title('Unconstrained stiffness matrix');
subplot(1,2,2)
spy(Kc)
title('Constrained stiffness matrix');

err = max(max(abs(Kc-Kc')));
if full(err) > 100*eps
  fprintf('\nMaximum deviation from symmetry of contrained stiffness matrix =\n');
  disp(err);
end
